<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv-SE" sourcelanguage="en">
  <context>
    <name>CmdDrawingAnnotation</name>
    <message>
      <location filename="../../Command.cpp" line="481"/>
      <source>Drawing</source>
      <translation>Ritning</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="482"/>
      <source>&amp;Annotation</source>
      <translation>&amp;Annotering</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="483"/>
      <location filename="../../Command.cpp" line="485"/>
      <source>Inserts an Annotation view in the active drawing</source>
      <translation>Infogar en annoteringsvy i den aktiva ritningen</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingClip</name>
    <message>
      <location filename="../../Command.cpp" line="529"/>
      <source>Drawing</source>
      <translation>Ritning</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="530"/>
      <source>&amp;Clip</source>
      <translation>&amp;Klipp</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="531"/>
      <location filename="../../Command.cpp" line="533"/>
      <source>Inserts a clip group in the active drawing</source>
      <translation>Infogar en Klipp-grupp i den aktiva ritningen</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingDraftView</name>
    <message>
      <location filename="../../Command.cpp" line="728"/>
      <source>Drawing</source>
      <translation>Ritning</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="729"/>
      <source>&amp;Draft View</source>
      <translation>&amp;Utkastvy</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="730"/>
      <location filename="../../Command.cpp" line="732"/>
      <source>Inserts a Draft view of the selected object(s) in the active drawing</source>
      <translation>Lägger till en Draft-vy av det valda objektet(en) i den aktiva ritningen</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingExportPage</name>
    <message>
      <location filename="../../Command.cpp" line="635"/>
      <source>File</source>
      <translation>Fil</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="636"/>
      <source>&amp;Export page...</source>
      <translation>&amp;Exportera sida...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="637"/>
      <location filename="../../Command.cpp" line="639"/>
      <source>Export a page to an SVG file</source>
      <translation>Exportera en sida till en SVG-fil</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingNewA3Landscape</name>
    <message>
      <location filename="../../Command.cpp" line="275"/>
      <source>Drawing</source>
      <translation>Ritning</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="276"/>
      <location filename="../../Command.cpp" line="277"/>
      <source>Insert new A3 landscape drawing</source>
      <translation>Infoga ny A3 landskap ritning</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingNewPage</name>
    <message>
      <location filename="../../Command.cpp" line="97"/>
      <source>Drawing</source>
      <translation>Ritning</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="98"/>
      <location filename="../../Command.cpp" line="99"/>
      <source>Insert new drawing</source>
      <translation>Sätt in ny ritning</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingNewView</name>
    <message>
      <location filename="../../Command.cpp" line="314"/>
      <source>Drawing</source>
      <translation>Ritning</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="315"/>
      <source>Insert view in drawing</source>
      <translation>Infoga vy i ritningen</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="316"/>
      <source>Insert a new View of a Part in the active drawing</source>
      <translation>Sätt in en ny vy av en Del i den aktiva ritningen</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingOpen</name>
    <message>
      <location filename="../../Command.cpp" line="60"/>
      <source>Drawing</source>
      <translation>Ritning</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="61"/>
      <source>Open SVG...</source>
      <translation>Öppna SVG...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="62"/>
      <source>Open a scalable vector graphic</source>
      <translation>Öppna en skalbar vektorgrafik</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingOpenBrowserView</name>
    <message>
      <location filename="../../Command.cpp" line="443"/>
      <source>Drawing</source>
      <translation>Ritning</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="444"/>
      <source>Open &amp;browser view</source>
      <translation>Öppna we&amp;bbläsarvy</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="445"/>
      <location filename="../../Command.cpp" line="447"/>
      <source>Opens the selected page in a browser view</source>
      <translation>Öppnar den valda sidan i en webbläsarvy</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingOrthoViews</name>
    <message>
      <location filename="../../Command.cpp" line="393"/>
      <source>Drawing</source>
      <translation>Ritning</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="394"/>
      <source>Insert orthographic views</source>
      <translation>Infoga ortografiska vyer</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="395"/>
      <source>Insert an orthographic projection of a part in the active drawing</source>
      <translation>Infoga en ortografisk projektion av en del i den aktiva ritningen</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingProjectShape</name>
    <message>
      <location filename="../../Command.cpp" line="692"/>
      <source>Drawing</source>
      <translation>Ritning</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="693"/>
      <source>Project shape...</source>
      <translation>Projekt former...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="694"/>
      <location filename="../../Command.cpp" line="695"/>
      <source>Project shape onto a user-defined plane</source>
      <translation>Projicera form på ett användardefinierat plan</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingSpreadsheetView</name>
    <message>
      <location filename="../../Command.cpp" line="759"/>
      <source>Drawing</source>
      <translation>Ritning</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="760"/>
      <source>&amp;Spreadsheet View</source>
      <translation>Kalkylblad&amp;svy</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="761"/>
      <location filename="../../Command.cpp" line="763"/>
      <source>Inserts a view of a selected spreadsheet in the active drawing</source>
      <translation>Lägger till en vy av valt Kalkylblad i den aktiva ritningen</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingSymbol</name>
    <message>
      <location filename="../../Command.cpp" line="574"/>
      <source>Drawing</source>
      <translation>Ritning</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="575"/>
      <source>&amp;Symbol</source>
      <translation>&amp;Symbol</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="576"/>
      <location filename="../../Command.cpp" line="578"/>
      <source>Inserts a symbol from a svg file in the active drawing</source>
      <translation>Infogar en symbol från en svg-fil i den aktiva ritningen</translation>
    </message>
  </context>
  <context>
    <name>DrawingGui::DrawingView</name>
    <message>
      <location filename="../../DrawingView.cpp" line="219"/>
      <source>&amp;Background</source>
      <translation>B&amp;akgrund</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="225"/>
      <source>&amp;Outline</source>
      <translation>&amp;Kontur</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="231"/>
      <source>&amp;Native</source>
      <translation>&amp;Nativ</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="235"/>
      <source>&amp;OpenGL</source>
      <translation>&amp;OpenGL</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="238"/>
      <source>&amp;Image</source>
      <translation>&amp;Bild</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="242"/>
      <source>&amp;High Quality Antialiasing</source>
      <translation>&amp;Högkvalitets kantutjämning</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="284"/>
      <source>Open SVG File</source>
      <translation>Öppna SVG-fil</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="285"/>
      <source>Could not open file '%1'.</source>
      <translation>Det gick inte att öppna fil '%1'.</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="408"/>
      <source>&amp;Renderer</source>
      <translation>&amp;Renderare</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="513"/>
      <source>Export PDF</source>
      <translation>Exportera PDF</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="514"/>
      <source>PDF file</source>
      <translation>PDF-fil</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="530"/>
      <source>Page sizes</source>
      <translation>Sidstorlekar</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="532"/>
      <location filename="../../DrawingView.cpp" line="545"/>
      <source>A0</source>
      <translation>A0</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="534"/>
      <location filename="../../DrawingView.cpp" line="547"/>
      <source>A1</source>
      <translation>A1</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="536"/>
      <location filename="../../DrawingView.cpp" line="549"/>
      <source>A2</source>
      <translation>A2</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="538"/>
      <location filename="../../DrawingView.cpp" line="551"/>
      <source>A3</source>
      <translation>A3</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="540"/>
      <location filename="../../DrawingView.cpp" line="553"/>
      <source>A4</source>
      <translation>A4</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="542"/>
      <location filename="../../DrawingView.cpp" line="555"/>
      <source>A5</source>
      <translation>A5</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="666"/>
      <source>Different orientation</source>
      <translation>Annan orientering</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="667"/>
      <source>The printer uses a different orientation than the drawing.
Do you want to continue?</source>
      <translation>Skrivaren använder en annan orientering än ritningen. Vill du fortsätta?</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="674"/>
      <location filename="../../DrawingView.cpp" line="682"/>
      <source>Different paper size</source>
      <translation>Annan pappersstorlek</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="675"/>
      <location filename="../../DrawingView.cpp" line="683"/>
      <source>The printer uses a different paper size than the drawing.
Do you want to continue?</source>
      <translation>Skrivaren använder en annan pappersstorlek än ritningen. Vill du fortsätta?</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="694"/>
      <source>Opening file failed</source>
      <translation>Fel vid filöppning</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="695"/>
      <source>Can't open file '%1' for writing.</source>
      <translation>Kan inte öppna filen '%1' för skrivning.</translation>
    </message>
  </context>
  <context>
    <name>DrawingGui::TaskOrthoViews</name>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="26"/>
      <source>Orthographic Projection</source>
      <translation>Ortografisk projektion</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="46"/>
      <location filename="../../TaskOrthoViews.ui" line="71"/>
      <location filename="../../TaskOrthoViews.ui" line="96"/>
      <location filename="../../TaskOrthoViews.ui" line="121"/>
      <location filename="../../TaskOrthoViews.ui" line="146"/>
      <location filename="../../TaskOrthoViews.ui" line="177"/>
      <location filename="../../TaskOrthoViews.ui" line="202"/>
      <location filename="../../TaskOrthoViews.ui" line="227"/>
      <location filename="../../TaskOrthoViews.ui" line="252"/>
      <location filename="../../TaskOrthoViews.ui" line="277"/>
      <location filename="../../TaskOrthoViews.ui" line="302"/>
      <location filename="../../TaskOrthoViews.ui" line="362"/>
      <source>Right click for axonometric settings</source>
      <translation>Högerklicka för axonometrisk inställningar</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="324"/>
      <source>Primary view</source>
      <translation>Primär vy</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="340"/>
      <source>Secondary Views</source>
      <translation>Sekundär vy</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="412"/>
      <source>General</source>
      <translation>Allmänt</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="421"/>
      <source>Auto scale / position</source>
      <translation>Auto skala / position</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="436"/>
      <source>Scale</source>
      <translation>Skala</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="468"/>
      <source>Top left x / y</source>
      <translation>Övre vänstra x / y</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="516"/>
      <source>Spacing dx / dy</source>
      <translation>Avstånd dx / dy</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="561"/>
      <source>Show hidden lines</source>
      <translation>Visa dolda linjer</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="568"/>
      <source>Show smooth lines</source>
      <translation>Visa utjämnade linjer</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="579"/>
      <source>Axonometric</source>
      <translation>Axonometrisk</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="587"/>
      <source>Axis out and right</source>
      <translation>Axel ut och höger</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="594"/>
      <source>Vertical tilt</source>
      <translation>Vertikal lutning</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="605"/>
      <location filename="../../TaskOrthoViews.ui" line="805"/>
      <source>X +ve</source>
      <translation>X +ve</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="610"/>
      <location filename="../../TaskOrthoViews.ui" line="685"/>
      <location filename="../../TaskOrthoViews.ui" line="810"/>
      <source>Y +ve</source>
      <translation>Y +ve</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="615"/>
      <location filename="../../TaskOrthoViews.ui" line="690"/>
      <location filename="../../TaskOrthoViews.ui" line="815"/>
      <source>Z +ve</source>
      <translation>Z +ve</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="620"/>
      <location filename="../../TaskOrthoViews.ui" line="820"/>
      <source>X -ve</source>
      <translation>X -ve</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="625"/>
      <location filename="../../TaskOrthoViews.ui" line="695"/>
      <location filename="../../TaskOrthoViews.ui" line="825"/>
      <source>Y -ve</source>
      <translation>Y -ve</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="630"/>
      <location filename="../../TaskOrthoViews.ui" line="700"/>
      <location filename="../../TaskOrthoViews.ui" line="830"/>
      <source>Z -ve</source>
      <translation>Z -ve</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="642"/>
      <source>Isometric</source>
      <translation>Isometrisk</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="647"/>
      <source>Dimetric</source>
      <translation>Dimetrisk</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="652"/>
      <source>Trimetric</source>
      <translation>Trimetrisk</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="660"/>
      <source> Scale</source>
      <translation> Skala</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="667"/>
      <source>View projection</source>
      <translation>Visa projektion</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="674"/>
      <source> Axis aligned up</source>
      <translation> Axel justerad uppåt</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="715"/>
      <location filename="../../TaskOrthoViews.ui" line="738"/>
      <source>Flip</source>
      <translation>Vänd</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="728"/>
      <source> Trimetric</source>
      <translation> Trimetrisk</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="756"/>
      <source>Projection</source>
      <translation>Projektion</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="767"/>
      <source>Third Angle</source>
      <translation>Tredje vinkel</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="772"/>
      <source>First Angle</source>
      <translation>Första vinkel</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="791"/>
      <source>View from:</source>
      <translation>Vy från:</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="838"/>
      <source>Axis aligned right:</source>
      <translation>Axel justerad åt höger:</translation>
    </message>
  </context>
  <context>
    <name>DrawingGui::TaskProjection</name>
    <message>
      <location filename="../../TaskDialog.cpp" line="51"/>
      <source>Visible sharp edges</source>
      <translation>Synliga vassa kanter</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="52"/>
      <source>Visible smooth edges</source>
      <translation>Synliga jämna kanter</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="53"/>
      <source>Visible sewn edges</source>
      <translation>Synliga sydda kanter</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="54"/>
      <source>Visible outline edges</source>
      <translation>Synliga kontur kanter</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="55"/>
      <source>Visible isoparameters</source>
      <translation>Synliga isoparametrar</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="56"/>
      <source>Hidden sharp edges</source>
      <translation>Dolda vassa kanter</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="57"/>
      <source>Hidden smooth edges</source>
      <translation>Dolda jämna kanter</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="58"/>
      <source>Hidden sewn edges</source>
      <translation>Dolda sydda kanter</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="59"/>
      <source>Hidden outline edges</source>
      <translation>Dolda kontur kanter</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="60"/>
      <source>Hidden isoparameters</source>
      <translation>Dolda isoparametrar</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="77"/>
      <source>Project shapes</source>
      <translation>Projekt former</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="91"/>
      <source>No active document</source>
      <translation>Inget aktivt dokument</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="92"/>
      <source>There is currently no active document to complete the operation</source>
      <translation>Det finns för närvarande inget aktivt dokument att slutföra åtgärden</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="97"/>
      <source>No active view</source>
      <translation>Ingen aktiv vy</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="98"/>
      <source>There is currently no active view to complete the operation</source>
      <translation>Det finns för närvarande ingen aktiv syn att slutföra åtgärden</translation>
    </message>
  </context>
  <context>
    <name>Drawing_NewPage</name>
    <message>
      <location filename="../../Command.cpp" line="223"/>
      <source>Landscape</source>
      <translation>Landskap</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="225"/>
      <source>Portrait</source>
      <translation>Porträtt</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="229"/>
      <source>%1%2 %3</source>
      <translation>%1%2 %3</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="234"/>
      <source>Insert new %1%2 %3 drawing</source>
      <translation>Infoga ny %1%2 %3 ritning</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="241"/>
      <source>%1%2 %3 (%4)</source>
      <translation>%1%2 %3 (%4)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="247"/>
      <source>Insert new %1%2 %3 (%4) drawing</source>
      <translation>Infoga nya %1%2 %3 (%4) i ritning</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Command.cpp" line="72"/>
      <location filename="../../Command.cpp" line="595"/>
      <source>Choose an SVG file to open</source>
      <translation>Välj en SVG fil att öppna</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="73"/>
      <location filename="../../Command.cpp" line="596"/>
      <location filename="../../Command.cpp" line="654"/>
      <source>Scalable Vector Graphic</source>
      <translation>Skalbar vektorgrafik</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="327"/>
      <location filename="../../Command.cpp" line="406"/>
      <location filename="../../Command.cpp" line="456"/>
      <location filename="../../Command.cpp" line="648"/>
      <location filename="../../Command.cpp" line="772"/>
      <source>Wrong selection</source>
      <translation>Fel val</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="328"/>
      <source>Select a Part object.</source>
      <translation>Välj ett Del objekt.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="336"/>
      <location filename="../../Command.cpp" line="415"/>
      <location filename="../../Command.cpp" line="496"/>
      <location filename="../../Command.cpp" line="544"/>
      <location filename="../../Command.cpp" line="589"/>
      <location filename="../../Command.cpp" line="778"/>
      <source>No page found</source>
      <translation>Ingen sida hittades</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="337"/>
      <location filename="../../Command.cpp" line="416"/>
      <location filename="../../Command.cpp" line="497"/>
      <location filename="../../Command.cpp" line="545"/>
      <location filename="../../Command.cpp" line="590"/>
      <location filename="../../Command.cpp" line="779"/>
      <source>Create a page first.</source>
      <translation>Skapa en sida först.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="407"/>
      <source>Select exactly one Part object.</source>
      <translation>Markera exakt ett delobjekt.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="457"/>
      <location filename="../../Command.cpp" line="649"/>
      <source>Select one Page object.</source>
      <translation>Välj ett sidobjekt.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="655"/>
      <source>All Files</source>
      <translation>Alla Filer</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="657"/>
      <source>Export page</source>
      <translation>Exportera sida</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="773"/>
      <source>Select exactly one Spreadsheet object.</source>
      <translation>Välj exakt ett sprängskissobjekt.</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.cpp" line="54"/>
      <location filename="../../TaskOrthoViews.cpp" line="982"/>
      <source>Make axonometric...</source>
      <translation>Gör axonometrisk...</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.cpp" line="55"/>
      <location filename="../../TaskOrthoViews.cpp" line="983"/>
      <source>Edit axonometric settings...</source>
      <translation>Redigera axonometriska inställningar...</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.cpp" line="56"/>
      <location filename="../../TaskOrthoViews.cpp" line="984"/>
      <source>Make orthographic</source>
      <translation>Gör ortografisk</translation>
    </message>
    <message>
      <location filename="../../ViewProviderPage.cpp" line="152"/>
      <source>Show drawing</source>
      <translation>Visa ritning</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="37"/>
      <source>Drawing</source>
      <translation>Ritning</translation>
    </message>
  </context>
</TS>
